@@ -1,6 +1,8 @@
-summary.intReg <- function(object, ...) {
+summary.intReg <- function(object, boundaries=FALSE, ...) {
    s <- NextMethod("summary", object, ...)
-   estimate <- coefTable(coef(object), stdEr(object), object$param$df)
+   estimate <- coefTable(coef(object, boundaries=boundaries),
+                         stdEr(object, boundaries=boundaries),
+                         object$param$df)
    s$estimate <- estimate
    s$param <- object$param
                            # supply the additional parameters
